==> freebsd-ubin-8.2.tar.bz2: usr.bin/calendar/paskha.c <==
/*-
 * Copyright (C) 1993-1996 by Andrey A. Chernov, Moscow, Russia.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <sys/cdefs.h>
__FBSDID("$FreeBSD: src/usr.bin/calendar/paskha.c,v 1.9.2.2.2.1 2010/12/21 17:09:25 kensmith Exp $");

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "calendar.h"

#define	PASKHA		"paskha"
#define	PASKHALEN	(sizeof(PASKHA) - 1)

/* return year day for Orthodox Easter using Gauss formula */
/* (old style result) */

int
paskha(int R) /*year*/
{
	int a, b, c, d, e;
	static int x = 15;
	static int y = 6;
	int *cumday;

	a = R % 19;
	b = R % 4;
	c = R % 7;
	d = (19 * a + x) % 30;
	e = (2 * b + 4 * c + 6 * d + y) % 7;
	cumday = cumdaytab[isleap(R)];
	return (((cumday[3] + 1) + 22) + (d + e));
}

==> freebsd-ubin-9.2_rc2.tar.bz2: usr.bin/calendar/paskha.c <==
/*-
 * Copyright (C) 1993-1996 by Andrey A. Chernov, Moscow, Russia.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <sys/cdefs.h>
__FBSDID("$FreeBSD: releng/9.2/usr.bin/calendar/paskha.c 218797 2011-02-18 13:41:45Z osa $");

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "calendar.h"

#define	PASKHA		"paskha"
#define	PASKHALEN	(sizeof(PASKHA) - 1)

/* return difference in days between Julian and Gregorian calendars */
int
j2g(int year)
{
	return (year < 1500) ?
		0 :
		10 + (year/100 - 16) - ((year/100 - 16) / 4);
}

/* return year day for Orthodox Easter using Gauss formula */
/* (new style result) */

int
paskha(int R) /*year*/
{
	int a, b, c, d, e;
	static int x = 15;
	static int y = 6;
	int *cumday;

	a = R % 19;
	b = R % 4;
	c = R % 7;
	d = (19 * a + x) % 30;
	e = (2 * b + 4 * c + 6 * d + y) % 7;
	cumday = cumdaytab[isleap(R)];
	return (((cumday[3] + 1) + 22) + (d + e) + j2g(R));
}
